tiled.client.dataframe.DaskDataFrameClient
==========================================

.. currentmodule:: tiled.client.dataframe

.. autoclass:: DaskDataFrameClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DaskDataFrameClient.__init__
      ~DaskDataFrameClient.download
      ~DaskDataFrameClient.export
      ~DaskDataFrameClient.new_variation
      ~DaskDataFrameClient.read
      ~DaskDataFrameClient.read_partition
      ~DaskDataFrameClient.refresh
      ~DaskDataFrameClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DaskDataFrameClient.context
      ~DaskDataFrameClient.formats
      ~DaskDataFrameClient.item
      ~DaskDataFrameClient.metadata
      ~DaskDataFrameClient.offline
      ~DaskDataFrameClient.path
      ~DaskDataFrameClient.uri
      ~DaskDataFrameClient.username
   
   